/*
 * Copyright (C) 2016 Inria
 *
 * This file is subject to the terms and conditions of the GNU Lesser
 * General Public License v2.1. See the file LICENSE in the top level
 * directory for more details.
 */

/**
 * @ingroup     drivers_bmp180
 * @{
 *
 * @file
 * @brief       SAUL adaption for BMP180 device
 *
 * @author      Hauke Petersen <hauke.petersen@fu-berlin.de>
 * @author      Alexandre Abadie <alexandre.abadie@inria.fr>
 *
 * @}
 */

#include <string.h>

#include "saul.h"
#include "bmp180.h"
#include "xtimer.h"

static int32_t temperature, pressure;

static int check_and_read_temperature(void *dev, phydat_t *res)
{
    bmp180_t *d = (bmp180_t *)dev;

    bmp180_read_temperature(d, &temperature);
    res->val[0] = temperature;
    res->unit = UNIT_TEMP_C;
    res->scale = -1;
    return 1;
}

static int check_and_read_pressure(void *dev, phydat_t *res)
{
    bmp180_t *d = (bmp180_t *)dev;

    bmp180_read_pressure(d, &pressure);

    res->val[0] = pressure/10;
    res->unit = UNIT_PA;
    res->scale = 1;
    return 1;
}

static int read_temperature(void *dev, phydat_t *res)
{
    return check_and_read_temperature(dev, res);
}

static int read_pressure(void *dev, phydat_t *res)
{
    return check_and_read_pressure(dev, res);
}

const saul_driver_t bmp180_temperature_saul_driver = {
    .read = read_temperature,
    .write = saul_notsup,
    .type = SAUL_SENSE_TEMP
};

const saul_driver_t bmp180_pressure_saul_driver = {
    .read = read_pressure,
    .write = saul_notsup,
    .type = SAUL_SENSE_PRESS
};
