/*
 * Copyright (C) 2015 Freie Universität Berlin
 *
 * This file is subject to the terms and conditions of the GNU Lesser
 * General Public License v2.1. See the file LICENSE in the top level
 * directory for more details.
 */

/**
 * @ingroup     examples
 * @{
 *
 * @file
 * @brief       Example application for demonstrating the RIOT network stack
 *
 * @author      Hauke Petersen <hauke.petersen@fu-berlin.de>
 *
 * @}
 */
#include <stdbool.h>
#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <inttypes.h>

#include <arpa/inet.h>
#include "../../boards/stm32f4discovery/include/board.h"
#include "../../boards/stm32f4discovery/include/periph_conf.h"
#include "periph/gpio.h"
#include "net/sock/udp.h"
#include "net/gnrc/ipv6.h"
#include "net/af.h"
#include "net/sixlowpan.h"
#include "net/gnrc/pktdump.h"
#include "shell.h"
#include "shell_commands.h"
#include "msg.h"
#include "thread.h"
#include "sched.h"
#include "thread.h"
#include "kernel_types.h"
#include "net/netstats.h"
#include "net/ipv6/addr.h"
#include "periph/timer.h"
#include "net/gnrc/ipv6/netif.h"
#include "net/gnrc/netif.h"
#include "net/gnrc/netapi.h"
#include "net/netopt.h"
#include "net/gnrc/pkt.h"
#include "net/gnrc/pktbuf.h"
#include "net/gnrc/netif/hdr.h"
#include "net/gnrc/sixlowpan/netif.h"
#include "net/fib.h"
#include "net/gnrc/udp.h"
#include "periph/pwm.h"
#include "od.h"
#include "net/sntp.h"
#include "net/ntp_packet.h"
#ifdef MODULE_SCHEDSTATISTICS
#include "xtimer.h"
#endif

#ifdef MODULE_TLSF
#include "tlsf.h"
#endif

#define MAIN_QUEUE_SIZE     (8)
/**
 * @brief   The maximal expected link layer address length in byte
 */
#define MAX_ADDR_LEN            (8U)

/**
 * @brief   The default IPv6 prefix length if not specified.
 */
#define SC_NETIF_IPV6_DEFAULT_PREFIX_LEN     (64)

#define _STACKSIZE      (THREAD_STACKSIZE_DEFAULT + THREAD_EXTRA_STACKSIZE_PRINTF)
#define MSG_TYPE_ISR    (0x3456)

#define PWM_FREQ 100
#define PWM_RES 100
#define DEADLINE 15000

// addr ipv6 link local node 1: fe80::3734:510e:3317:3402
uint8_t node1[16]={0xfe,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x37,0x34,0x51,0x0e,0x33,0x17,0x34,0x02};
// addr ipv6 link local node 2: fe80::3634:5110:3473:3762
uint8_t node2[16]={0xfe,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x36,0x34,0x51,0x10,0x34,0x73,0x37,0x62};
//addr ipv6 link local node 3: fe80::3634:5110:3471:3766
uint8_t node3[16]={0xfe,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x37,0x34,0x51,0x0b,0x33,0x0a,0x34,0x1e};

//static char _stack_server[GNRC_PKTDUMP_STACKSIZE];
char sock_server_stack[THREAD_STACKSIZE_MAIN];
char sock_client_stack[THREAD_STACKSIZE_MAIN];
char sock_time_server_stack[THREAD_STACKSIZE_MAIN];
// static gnrc_netreg_entry_t server = GNRC_NETREG_ENTRY_INIT_PID(GNRC_NETREG_DEMUX_CTX_ALL,
//                                                                KERNEL_PID_UNDEF);
// 
// kernel_pid_t gnrc_server_pid = KERNEL_PID_UNDEF;
// 
kernel_pid_t server, client, time_server;
int ordre = 0;
int64_t offset = 0;
int timer_run = 0;
int tourne = 0;
sock_udp_ep_t local = SOCK_IPV6_EP_ANY;
sock_udp_t sock; 
sock_udp_ep_t local_ntp = SOCK_IPV6_EP_ANY;
sock_udp_t sock_ntp; 
static ntp_packet_t sntp_packet;

typedef struct tableau {
  uint32_t heure_actuelle;
}Data;


void *sock_time_server_thread(void *arg)
{
    (void) arg;
    local_ntp.port = NTP_PORT;

    if (sock_udp_create(&sock_ntp, &local_ntp, NULL, 0) < 0) {
	  puts("Error creating UDP sock");
	  return NULL;
      }

      while (1) {
	  sock_udp_ep_t remote;
	  ssize_t res;

	  if ((res = sock_udp_recv(&sock_ntp,&sntp_packet, sizeof(sntp_packet), SOCK_NO_TIMEOUT,
				  &remote)) >= 0) {
	      puts("Received a message");
	    //printf("TT: %lu\n", byteorder_ntohl(sntp_packet.transmit.seconds));
	    
	    // printf("%c\n",remote.addr.ipv6[15]);
	    //xtimer_ticks64_t now = xtimer_now64();
	    // heure actuelle du serveur
	    sntp_packet.receive.seconds=byteorder_htonl( xtimer_now_usec());
	    sntp_packet.origin.seconds=sntp_packet.transmit.seconds;
	    sntp_packet.transmit.seconds=byteorder_htonl( xtimer_now_usec());
	    //printf("heure actuelle : %lu\n",xtimer_now_usec());
	    //printf("TT2: %lu\n", byteorder_ntohl(sntp_packet.transmit.seconds));
	  //memset(&sntp_packet, 0, sizeof(sntp_packet)); 
	    //ntp_packet_set_vn(&sntp_packet);
	    //ntp_packet_set_mode(&sntp_packet, NTP_MODE_SERVER);
	      if (sock_udp_send(&sock_ntp, &sntp_packet, sizeof(sntp_packet), &remote) < 0) {
		  puts("Error sending reply");
	      }
	  }
      }
    return NULL;
}

void *sock_server_thread(void *arg)
{
  (void) arg;
  Data buf;
  int deadline;
  local.port = 1234;
  sock_udp_ep_t server = { .port = NTP_PORT, .family = AF_INET6 };
  ipv6_addr_from_str((ipv6_addr_t *)&server.addr, "dead:beef::3402");
    
  if (sock_udp_create(&sock, &local, NULL, 0) < 0) {
    puts("Error creating UDP sock");
    return NULL;
  }
  if (sntp_sync(&server, SOCK_NO_TIMEOUT) < 0) {
    puts("Error in synchronization");
    return NULL;
  }
  offset = sntp_get_offset();
  printf("offset : %i\n",(int)offset);
  
  while (1) {
    sock_udp_ep_t remote;
    ssize_t res;
    if ((res = sock_udp_recv(&sock, &buf, sizeof(buf), SOCK_NO_TIMEOUT,&remote)) >= 0) {
      deadline = xtimer_now_usec() + offset - buf.heure_actuelle;
      printf("tps de transmission : %i\n",deadline);
    }
  }
    return NULL;
}

void *sock_client_thread(void *arg)
{
  (void) arg;
  Data data;
//   data.donnees[0] = 'g';
//   data.donnees[1] = 'o';
  //uint8_t paquet[];
  sock_udp_ep_t remote = { .family = AF_INET6 };
  
  remote.port = 1234;
  remote.addr.ipv6[0] = 0xde;
  remote.addr.ipv6[1] = 0xad;
  remote.addr.ipv6[2] = 0xbe;
  remote.addr.ipv6[3] = 0xef;
  remote.addr.ipv6[14] = 0x37;
  remote.addr.ipv6[15] = 0x62;

  while (1) {
    data.heure_actuelle = xtimer_now_usec();
    printf("%d\n",sizeof(data));
    if (sock_udp_send(&sock, &data, sizeof(data), &remote) < 0) {
      puts("Error sending message");
    }
    xtimer_sleep(1);
  }
  return NULL;
}


 
 static void _init_interface(void)
 {
   kernel_pid_t ifs[GNRC_NETIF_NUMOF];
   ipv6_addr_t addr = IPV6_ADDR_UNSPECIFIED;
   ipv6_addr_t tmp_addr= IPV6_ADDR_UNSPECIFIED;
   uint8_t hwaddr[MAX_ADDR_LEN];
   int res;
   
   gnrc_netif_get(ifs);
   
   //addresses gobales
   addr.u8[0] = 0xde;
   addr.u8[1] = 0xad;
   addr.u8[2] = 0xbe;
   addr.u8[3] = 0xef;
   
   res = gnrc_netapi_get(ifs[0], NETOPT_ADDRESS, 0, hwaddr, sizeof(hwaddr));
   
   if (res >= 0) {
     addr.u8[14] = *hwaddr;
     addr.u8[15] = *(hwaddr+1);
   }
   memcpy(tmp_addr.u8,addr.u8,IPV6_ADDR_BIT_LEN);
   
   gnrc_ipv6_netif_add_addr(ifs[0], &addr, 64, GNRC_IPV6_NETIF_ADDR_FLAGS_UNICAST);
   /* model ipv6 addr: dead:beef::Hwaddr */
   if((addr.u8[14]==0x34)&&(addr.u8[15]==0x02)){
     
     tmp_addr.u8[14] = 0x34;
     tmp_addr.u8[15] = 0x1e;
     //fibroute dest: dead:beef::3766 via fe80::3634:5110:3473:3762
     fib_add_entry(&gnrc_ipv6_fib_table, ifs[0],tmp_addr.u8, IN6ADDRSZ, 0,node2, IN6ADDRSZ, 0, FIB_LIFETIME_NO_EXPIRE);
     tmp_addr.u8[14] = 0x37;
     tmp_addr.u8[15] = 0x62;
     //fibroute dest: dead:beef::3762 via fe80::3634:5110:3473:3762
     fib_add_entry(&gnrc_ipv6_fib_table, ifs[0],tmp_addr.u8, IN6ADDRSZ, 0,node2, IN6ADDRSZ, 0, FIB_LIFETIME_NO_EXPIRE);
     client=thread_create(sock_client_stack,sizeof(sock_client_stack),8,THREAD_CREATE_STACKTEST,sock_client_thread,NULL,"sock_client_thread");
     //xtimer_usleep(10000);
     time_server=thread_create(sock_time_server_stack,sizeof(sock_time_server_stack),6,THREAD_CREATE_STACKTEST,sock_time_server_thread,NULL,"sock_time_server_thread");
   //  xtimer_usleep(200);
   }else if((addr.u8[14]==0x37)&&(addr.u8[15]==0x62)){
     tmp_addr.u8[14] = 0x34;
     tmp_addr.u8[15] = 0x1e;
     //fibroute dest: dead:beef::3766 via fe80::3634:5110:3471:3766
     fib_add_entry(&gnrc_ipv6_fib_table, ifs[0],tmp_addr.u8, IN6ADDRSZ, 0,node3, IN6ADDRSZ, 0, FIB_LIFETIME_NO_EXPIRE);
     tmp_addr.u8[14] = 0x34;
     tmp_addr.u8[15] = 0x02;
     //fibroute dest: dead:beef::3402 via fe80::3734:510e:3317:3402
     fib_add_entry(&gnrc_ipv6_fib_table, ifs[0],tmp_addr.u8, IN6ADDRSZ, 0,node1, IN6ADDRSZ, 0, FIB_LIFETIME_NO_EXPIRE);
     server=thread_create(sock_server_stack,sizeof(sock_server_stack),6,THREAD_CREATE_STACKTEST,sock_server_thread,NULL,"sock_server_thread");
   }else if((addr.u8[14]==0x34)&&(addr.u8[15]==0x1e)){
     tmp_addr.u8[14] = 0x34;
     tmp_addr.u8[15] = 0x02;
     //fibroute dest: dead:beef::3402 via fe80::3634:5110:3473:3762
     fib_add_entry(&gnrc_ipv6_fib_table, ifs[0],tmp_addr.u8, IN6ADDRSZ, 0,node2, IN6ADDRSZ, 0, FIB_LIFETIME_NO_EXPIRE); tmp_addr.u8[14] = 0x37;
     tmp_addr.u8[14] = 0x37;
     tmp_addr.u8[15] = 0x62;
     //fibroute dest: dead:beef::3762 via fe80::3634:5110:3473:3762
     fib_add_entry(&gnrc_ipv6_fib_table, ifs[0],tmp_addr.u8, IN6ADDRSZ, 0,node2, IN6ADDRSZ, 0, FIB_LIFETIME_NO_EXPIRE);
     //start_server("1234");
      server=thread_create(sock_server_stack,sizeof(sock_server_stack),6,THREAD_CREATE_STACKTEST,sock_server_thread,NULL,"sock_server_thread");
     
     
   }else{
     puts("new node ?");
   }
 }

static msg_t _main_msg_queue[MAIN_QUEUE_SIZE];

extern int udp_cmd(int argc, char **argv);

static const shell_command_t shell_commands[] = {
    { "udp", "send data over UDP and listen on UDP ports", udp_cmd },
    { NULL, NULL, NULL }
};


int main(void)
{

    msg_init_queue(_main_msg_queue, MAIN_QUEUE_SIZE);
    puts("RIOT network stack example application");
    _init_interface();
    
    /* start shell */
    puts("All up, running the shell now");
    char line_buf[SHELL_DEFAULT_BUFSIZE];
    shell_run(shell_commands, line_buf, SHELL_DEFAULT_BUFSIZE);
    
    /* should be never reached */
    return 0;
}
